@@ -7,7 +7,8 @@ library(elevatr)
 data("pt_df")
 data("sp_big")
 data("lake")
-skip_on_os("solaris")
+skip_on_cran()
+#skip_on_os("solaris")
 ll_prj  <- "EPSG:4326"
 aea_prj <- "EPSG:5072"
 
@@ -29,14 +30,12 @@ mts <- rbind(mt_wash,mt_mans)
 mts$name <- c("Mount Washington", "Mount Mansfield")
 
 test_that("data frame with more extra columns work", {
-  skip_on_cran()
   
   mts_with_names_and_elevation <- get_elev_point(mts, ll_prj)
   expect_true("name" %in% names(mts_with_names_and_elevation))
 })
 
 test_that("proj_expand works",{
-  skip_on_cran()
   
   suppressWarnings({
   mans_sp <- SpatialPoints(coordinates(data.frame(x = -72.8145, y = 44.5438)),
@@ -54,7 +53,6 @@ test_that("proj_expand works",{
 })
 
 test_that("loc_check errors correctly", {
-  skip_on_cran()
   
   expect_error(get_elev_point(locations = pt_df), 
                "Please supply a valid crs via locations or prj.")
@@ -69,7 +67,6 @@ test_that("loc_check errors correctly", {
 })
 
 test_that("Z of 1 or 0 works in get_tilexy",{
-  skip_on_cran()
   
   suppressWarnings({
   sp_sm_1 <- get_elev_raster(sp_sm_prj, z = 1, clip = "bbox")
